[前][次][番号順一覧][スレッド一覧]

ruby-changes:20659

From: naruse <ko1@a...>
Date: Thu, 28 Jul 2011 00:30:22 +0900 (JST)
Subject: [ruby-changes:20659] naruse:r32707 (trunk): * test/fileutils/test_fileutils.rb: add OpenBSD case.

naruse	2011-07-28 00:30:11 +0900 (Thu, 28 Jul 2011)

  New Revision: 32707

  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=rev&revision=32707

  Log:
    * test/fileutils/test_fileutils.rb: add OpenBSD case.
      patched by Jeremy Evans [ruby-core:38530] see #5097
    
    * test/ruby/test_process.rb: ditto.

  Modified files:
    trunk/ChangeLog
    trunk/test/fileutils/test_fileutils.rb
    trunk/test/ruby/test_process.rb

Index: ChangeLog
===================================================================
--- ChangeLog	(revision 32706)
+++ ChangeLog	(revision 32707)
@@ -1,3 +1,10 @@
+Thu Jul 28 00:28:15 2011  NARUSE, Yui  <naruse@r...>
+
+	* test/fileutils/test_fileutils.rb: add OpenBSD case.
+	  patched by Jeremy Evans [ruby-core:38530] see #5097
+
+	* test/ruby/test_process.rb: ditto.
+
 Wed Jul 27 22:46:59 2011  CHIKANAGA Tomoyuki  <nagachika00@g...>
 
 	* test/rinda/test_rinda.rb (test_remote_array_and_hash):
Index: test/ruby/test_process.rb
===================================================================
--- test/ruby/test_process.rb	(revision 32706)
+++ test/ruby/test_process.rb	(revision 32707)
@@ -1191,8 +1191,10 @@
   end
 
   def test_wait_and_sigchild
-    if /freebsd/ =~ RUBY_PLATFORM
-      skip "this randomly fails on FreeBSD"
+    if /freebsd|openbsd/ =~ RUBY_PLATFORM
+      # this relates #4173
+      # When ruby can use 2 cores, signal and wait4 may miss the signal.
+      skip "this fails on FreeBSD and OpenBSD on multithreaded environment"
     end
     signal_received = []
     Signal.trap(:CHLD)  { signal_received << true }
Index: test/fileutils/test_fileutils.rb
===================================================================
--- test/fileutils/test_fileutils.rb	(revision 32706)
+++ test/fileutils/test_fileutils.rb	(revision 32707)
@@ -913,8 +913,8 @@
     # FreeBSD ufs and tmpfs don't allow to change sticky bit against
     # regular file. It's slightly strange. Anyway it's no effect bit.
     # see /usr/src/sys/ufs/ufs/ufs_chmod()
-    # NetBSD also denies it.
-    if /freebsd|netbsd/ !~ RUBY_PLATFORM
+    # NetBSD and OpenBSD also denies it.
+    if /freebsd|netbsd|openbsd/ !~ RUBY_PLATFORM
       chmod "u+t,o+t", 'tmp/a'
       assert_equal 07500, File.stat('tmp/a').mode & 07777
       chmod "a-t,a-s", 'tmp/a'

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]